@@ -24,7 +24,7 @@ import os, json, collections, concurrent.futures, traceback, sys, time, gc
 from multiprocessing import cpu_count
 import dateutil.parser
 from .. import logger
-from ..compat import basestring, THREAD_TIMEOUT_MAX
+from ..compat import basestring, THREAD_TIMEOUT_MAX, Mapping
 from ..exceptions import DXError
 import numbers
 import binascii
@@ -248,7 +248,7 @@ def merge(d, u):
     Example: merge({"a": {"b": 1, "c": 2}}, {"a": {"b": 3}}) = {"a": {"b": 3, "c": 2}}
     """
     for k, v in u.items():
-        if isinstance(v, collections.Mapping):
+        if isinstance(v, Mapping):
             r = merge(d.get(k, {}), v)
             d[k] = r
         else:
